<?php

switch ($messaggio) {

case "Torna indietro":  			$messaggio = "Retournez"; break;
case "Privilegi dell'utente":  			$messaggio = "Droits de l'usager"; break;
case "Privilegi <b>globali</b>":  		$messaggio = "Droits <b>globaux</b>"; break;
case "Modifica delle proprie personalizzazioni":	$messaggio = "Modifiez ses propres personnalisations"; break;
case "Si":  					$messaggio = "Oui"; break;
case "No":  					$messaggio = "Non"; break;
case "Inserimento di nuovi clienti":  		$messaggio = "Insérez les nouveaux clients"; break;
case "Possibilità di vedere ed utilizzare nelle prenotazioni i clienti già inseriti":	$messaggio = "Possibilité de voir et utiliser dans les réservations les clients déjà insérés"; break;
case "Modifica e cancellazione dei clienti già inseriti":  	$messaggio = "Modifiez et supprimez les clients déjà insérés"; break;
case "Inserire in tutti i cognomi dei clienti inseriti da questo utente":	$messaggio = "Insérer dans tous les noms des clients insérés par cet utilisateur"; break;
case "Un prefisso":  				$messaggio = "Un préfixe"; break;
case "Un suffisso":  				$messaggio = "Un suffixe"; break;
case "Niente":  				$messaggio = "Rien"; break;
case "Modifica i privilegi globali":  		$messaggio = "Modifiez les privilèges globaux"; break;
case "Privilegi per l'anno":			$messaggio = "Droits pour l'année"; break;
case "Anno disattivato":  			$messaggio = "Année désactivée"; break;
case "Attiva":  				$messaggio = "Activez"; break;
case "Anno attivato":  				$messaggio = "Année activée"; break;
case "Disattiva":  				$messaggio = "Désactivez"; break;
case "Prenotazioni inseribili solo nei periodi della regola di assegnazione 1 con le motivazioni selezionate":	$messaggio = "Réservations insérables seulement dans les périodes de la règle 1 d'attribution avec les motivations choisies"; break;
case "nessuna":  				$messaggio = "personne"; break;
case "Applica la regola 1":  			$messaggio = "Appliquez la règle 1"; break;
case "Sempre":  				$messaggio = "Toujours"; break;
case "Solo per regole non selezionate":  	$messaggio = "Seulement pour des règles non choisies"; break;
case "Mai":  					$messaggio = "Jamais"; break;
case "Mai, ma non spostare altre prenotazioni in periodi delle regole non selezionate se non vi si possono inserire prenotazioni":	$messaggio = "Jamais, mais ne déplacez pas d'autres réservations dans les périodes des règles non choisies s'il n'est pas autorisé pour insérer des réservations ici"; break;
case "Permetti l'uso di tutte le <i>tariffe</i> nell'inserimento e modifica delle prenotazioni":	$messaggio = "Permettez l'utilisation de tous <i>tarifs</i> quand insertion et modification des réservations"; break;
case "Permetti l'uso solo delle <i>tariffe</i> selezionate nell'inserimento e modifica delle prenotazioni":	$messaggio = "Permettez l'utilisation de seulemnt les <i>tarifs</i> sélectionnés quand insertion et modification des réservations"; break;
case "tariffa":  				$messaggio = "tarif"; break;
case "Permetti l'uso di tutti i <i>costi aggiuntivi</i> nell'inserimento e modifica delle prenotazioni":	$messaggio = "Permettez l'utilisation de tous les <i>surcoûts</i> quand insertion et modification des réservations"; break;
case "Permetti l'uso solo dei <i>costi aggiuntivi</i> selezionati nell'inserimento e modifica delle prenotazioni":	$messaggio = "Permettez l'utilisation seulement des <i>surcoûts</i> choisis quand insertion et modification des réservations"; break;
case "Costo unico":  				$messaggio = "Coût simple"; break;
case "Costo settimanale":  			$messaggio = "Coût hebdomadaire"; break;
case "Costo giornaliero":  			$messaggio = "Coût quotidien"; break;
case "Non permettere l'inserimento di <i>nuove prenotazioni</i>":	$messaggio = "Ne permettez pas l'insertion de <i>nouvelles réservations</i>"; break;
case "Permetti l'inserimento di <i>nuove prenotazioni</i> con le seguenti possibilità":	$messaggio = "Permettre l'insertion de <i>nouvelles réservations</i> avec les possibilités suivantes"; break;
case "Possibilità di confermare la prenotazione":	$messaggio = "Possibilité de confirmer la réservation"; break;
case "Possibilità di inserire uno sconto":  	$messaggio = "Possibilité d'insérer un escompte"; break;
case "Possibilità di inserire dei costi aggiuntivi":	$messaggio = "Possibilité d'insérer des surcoûts"; break;
case "Possibilità di inserire il numero di persone":	$messaggio = "Possibilité d'insérer un nombre de personnes"; break;
case "Possibilità di inserire prenotazioni anche in periodi già iniziati":	$messaggio = "Possibilité d'insérer des réservations même en périodes déjà entamées"; break;
case "Prenotazioni che possono essere <i>modificate</i>":	$messaggio = "Réservations qui peuvent être <i>modifiées</i>"; break;
case "Tutte":  					$messaggio = "Toutes"; break;
case "Nessuna":  				$messaggio = "Personne"; break;
case "Possibilità di modificare la data iniziale o finale":	$messaggio = "Possibilité de modifier la date de commencement ou de fin"; break;
case "Possibilità di modificare la tariffa":  	$messaggio = "Possibilité de modifier le tarif"; break;
case "Si, con regola 2 a scelta":  		$messaggio = "Oui, Avec la règle 2 à choix"; break;
case "Si, sempre con regola 2":  		$messaggio = "Oui, toujours avec la règle 2"; break;
case "Possibilità di modificare il numero delle persone":	$messaggio = "Possibilité de modifier le nombre de personnes"; break;
case "Possibilità di modificare il commento":  	$messaggio = "Possibilité de modifier le commentaire"; break;
case "Possibilità di modificare lo sconto":  	$messaggio = "Possibilité de modifier l'escompte"; break;
case "Possibilità di modificare i costi aggiuntivi":	$messaggio = "Possibilité de modifier le surcoûts"; break;
case "Possibilità di modificare i soldi pagati e la conferma":	$messaggio = "Possibilité de modifier l'argent payé et la confirmation"; break;
case "Solo la conferma":  			$messaggio = "Seulement la confirmation"; break;
case "Possibilità di modificare prenotazioni già iniziate":	$messaggio = "Possibilité de modifier les réservations déjà commencées"; break;
case "Prenotazioni non più modificabili dopo un certo numero di ore dopo l'inserzione":	$messaggio = "Réservations non modifiables après un certain nombre d'heures après insertion"; break;
case "ore":  					$messaggio = "heures"; break;
case "Possibilità di cancellare le prenotazioni":	$messaggio = "Possibilité de supprimer des réservations"; break;
case "Solo quelle non iniziate":  		$messaggio = "Seulement celles non commencées"; break;
case "Prenotazioni non più cancellabili dopo un certo numero di ore dopo l'inserzione":	$messaggio = "Réservations non supprimables après un certain nombre d'heures après insertion"; break;
case "Possibilità di inserire e cancellare le <i>spese</i>":	$messaggio = "Possibilité d'insérer et supprimer <i>paiements</i>"; break;
case "Possibilità di inserire e cancellare le <i>entrate</i>":	$messaggio = "Possibilité d'insérer et supprimer <i>reçus</i>"; break;
case "<i>Sottrarre le entrate</i> dal totale delle prenotazioni":	$messaggio = "<i>Soustraire les reçus</i> du total des réservations"; break;
case "A scelta":  				$messaggio = "À choix"; break;
case "Immettere come <i>persona</i> che inserisce le spese o le entrate":	$messaggio = "Introduire comme <i>personne</i> qui insère des paiements et des reçus"; break;
case "Il nome dell'utente":  			$messaggio = "Le nom de l'usager"; break;
case "Chiedere":  				$messaggio = "Demandez"; break;
case "Nessuno":  				$messaggio = "Personne"; break;
case "Possibilità di vedere la <i>tabella dei mesi</i>":	$messaggio = "Possibilité de voir la <i>tables avec les mois</i>"; break;
case "Possibilità di vedere la <i>tabella con tutte le prenotazioni</i>":	$messaggio = "Possibilité de voir la <i>table avec toutes les réservations</i>"; break;
case "Possibilità di vedere le <i>tabelle con le entrate e le uscite</i>":	$messaggio = "Possibilité de voir la <i>table avec des paiements et des paiements</i>"; break;
case "entrate/uscite proprie":  		$messaggio = "own payments/receipts"; break;
case "entrate/uscite dai suoi gruppi":  	$messaggio = "payments/receipts from his groups"; break;
case "Possibilità di vedere la <i>tabella con i periodi e le tariffe</i>":	$messaggio = "Possibilité de voir la <i>table avec les périodes et les prix</i>"; break;
case "Solo con tariffe consentite":  		$messaggio = "Seulement avec des prix autorisés"; break;
case "Possibilità di vedere la <i>tabella con le regole di assegnazione</i>":	$messaggio = "Possibilité de voir la <i>table avec des règles attribuées</i>"; break;
case "Solo con regole consentite":  		$messaggio = "Seulement avec des règles autorisées"; break;
case "Modifica i privilegi dell'anno":  	$messaggio = "Modifiez les droits de l'année"; break;
case "Testo del prefisso/suffisso dei clienti":	$messaggio = "Texte du préfixe/suffixe des clients"; break;
case "L'utente":  				$messaggio = "L'utilisateur"; break;
case "potrà modificare le sue <b>personalizzazioni</b>":	$messaggio = "il pourra modifier ses <b>personnalisations</b>"; break;
case "non potrà più modificare le sue <b>personalizzazioni</b>":	$messaggio = "il ne pourra plus modifier ses <b>personnalisations</b>"; break;
case "potrà inserire <b>nuovi clienti</b>":  	$messaggio = "il pourra insérer <b>des nouveaux clients</b>"; break;
case "non potrà più inserire <b>nuovi clienti</b>":	$messaggio = "il ne pourra plus insérer <b>des nouveaux clients</b>"; break;
case "potrà modificare <b>tutti i clienti</b>":	$messaggio = "il pourra modifier <b>tous les clients</b>"; break;
case "potrà modificare solo i <b>propri clienti</b>":	$messaggio = "il pourra modifier ses <b>propres clients</b>"; break;
case "non potrà più modificare <b>nessun cliente</b>":	$messaggio = "il ne pourra plus modifier <b>aucun client</b>"; break;
case "non potrà vedere <b>nessun cliente</b>":	$messaggio = "il ne pourra pas voir <b>aucun client</b>"; break;
case "potrà vedere solo i <b>propri clienti</b>":	$messaggio = "il pourra voir seulement <b>ses clients</b>"; break;
case "potrà vedere <b>tutti i clienti</b>":  	$messaggio = "il puorra voir <b>tous les clients</b>"; break;
case "Verrà aggiunto un <b>prefisso</b> a tutti i cognomi dei clienti inseriti dall'utente":	$messaggio = "Un <b>préfixe</b> sera ajouté à tous les noms de famille des clients insérés par l'utilisateur"; break;
case "Verrà aggiunto un <b>suffisso</b> a tutti i cognomi dei clienti inseriti dall'utente":	$messaggio = "Un <b>suffixe</b> sera ajouté à tous les noms de famille des clients insérés par l'utilisateur"; break;
case "Non verrà aggiunto più alcun <b>prefisso/suffisso</b> ai cognomi dei clienti inseriti dall'utente":	$messaggio = "Un <b>préfixe/suffixe</b> ne sera plus ajouté aux noms de famille des clients insérés par l'utilisateur"; break;
case "Il nuovo testo del <b>prefisso/suffisso</b> dei cognomi dei clienti inseriti dall'utente":	$messaggio = "Le nouveau texte du <b>préfixe/suffixe</b> des noms de famille de clients insérés par l'utilisateur"; break;
case "sarà":  					$messaggio = "il sera"; break;
case "Continua":  				$messaggio = "Continuez"; break;
case "potrà inserire le sue prenotazioni in <b>tutti i periodi</b> del":	$messaggio = "il pourra insérer ses réservations de <b>dans tous les périodes</b> de"; break;
case "potrà inserire le sue prenotazioni solo nei <b>periodi della regola 1</b> selezionati nel":	$messaggio = "il pourra insérer ses réservations seulement dans  <b>les périodes de la règle 1</b> sélectionnées dans"; break;
case "Verranno cambiate le motivazioni selezionate della <b>regola 1</b> per l'anno":	$messaggio = "Les motivations sélectionnées de la <b>règle 1</b> seront changées pour l'année"; break;
case "verrà avvisato <b>sempre</b> quando inserirà prenotazioni nei periodi delle regole 1 del":	$messaggio = "il sera <b>toujours</b> averti lorsque il insérera des réservations dans les périodes des règles 1 de"; break;
case "verrà avvisato solo quando inserirà prenotazioni nei periodi delle regole 1 <b>non selezionate</b> del":	$messaggio = "il sera averti seulement lorsque il insérera des réservations dans les périodes des règles 1 <b>non sélectionnées</b> de"; break;
case "non verrà avvisato <b>mai</b> quando inserirà prenotazioni nei periodi delle regole 1 del":	$messaggio = "il ne sera <b>jamais</b> averti  lorsque il insérera des réservations dans les périodes des règles 1 de"; break;
case "potrà utilizzare <b>tutte le tariffe</b> del":	$messaggio = "il pourra utiliser <b>tous les tarifs</b> de"; break;
case "potrà utilizzare solo le <b>tariffe selezionate</b> del":	$messaggio = "il pourra utiliser seulement <b>les tarifs sélectionnés</b> de"; break;
case "Verranno cambiate le <b>tariffe selezionate</b> da utilizzare per l'anno":	$messaggio = "<b>Les tarifs sélectionnés</b> à utiliser seront changés pour l'année"; break;
case "potrà utilizzare <b>tutti i costi aggiuntivi</b> del":	$messaggio = "il pourra utiliser <b>tous les surcoûts</b> de"; break;
case "potrà utilizzare solo i <b>costi aggiuntivi selezionati</b> del":	$messaggio = "il pourra utiliser seulement <b>les surcoûts sélectionnés</b> de"; break;
case "Verranno cambiati i <b>costi aggiuntivi</b> da utilizzare per l'anno":	$messaggio = "il pourra changé <b>les surcoûts sélectionnés</b> à utiliser pour l'année"; break;
case "non potrà inserire <b>nuove prenotazioni</b> nel":	$messaggio = "Il ne pourra pas insérer des <b>nouvelles réservations</b> dans"; break;
case "potrà inserire <b>nuove prenotazioni</b> nel":	$messaggio = "Il pourra insérer des <b>nouvelles réservations</b> dans"; break;
case "non potrà <b>confermare</b> le nuove prenotazioni inserite nel":	$messaggio = "il ne pourra pas <b>confirmer</b> les nouvelles réservations insérées dans"; break;
case "potrà <b>confermare</b> le nuove prenotazioni inserite nel":	$messaggio = "il pourra <b>confirmer</b> les nouvelles réservations insérées dans"; break;
case "non potrà inserire uno <b>sconto</b> quando inserisce nuove prenotazioni nel":	$messaggio = "il ne pourra pas insérer <b>un escompte</b> lorsque il insère des nouvelles réservations dans"; break;
case "potrà inserire uno <b>sconto</b> quando inserisce nuove prenotazioni nel":	$messaggio = "il pourra insérer> <b>un escompte</b lorsque il insère des nouvelles réservations dans"; break;
case "non potrà inserire dei <b>costi aggiuntivi</b> quando inserisce nuove prenotazioni nel":	$messaggio = "il ne pourra pas insérer les <b>surcoûts</b> lorsque il insère des nouvelles réservations dans"; break;
case "potrà inserire dei <b>costi aggiuntivi</b> quando inserisce nuove prenotazioni nel":	$messaggio = "il pourra insérer <b>surcoûts</b> lorsque il insère des nouvelles réservations dans"; break;
case "non potrà inserire il <b>numero delle persone</b> quando inserisce nuove prenotazioni nel":	$messaggio = "il ne pourra pas insérer le <b>nombre de personnes</b> lorsque il insère des nouvelles réservations dans"; break;
case "potrà inserire il <b>numero delle persone</b> quando inserisce nuove prenotazioni nel":	$messaggio = "il pourra insérer le <b>nombre de personnes</b> lorsque il insère des nouvelles réservations dans"; break;
case "non potrà inserire nuove prenotazioni in <b>periodi già iniziati</b> nel":	$messaggio = "il ne pourra pas insérer de nouvelles réservations dans les <b>périodes déjà entamées</b>"; break;
case "potrà inserire nuove prenotazioni in <b>periodi già iniziati</b> nel":	$messaggio = "il pourra insérer de nouvelles réservations dans les <b>périodes déjà entamées</b>"; break;
case "non potrà modificare <b>nessuna prenotazione</b> nel":	$messaggio = "il ne pourra pas modifier <b>aucune réservation</b> dedans"; break;
case "potrà modificare solo le <b>sue prenotazioni</b> nel":	$messaggio = "il pourra modifier seulement ses <b>propres réservations</b> dedans"; break;
case "potrà modificare <b>tutte le prenotazioni</b> nel":	$messaggio = "il pourra modifier <b>toutes les réservations</b> dedans"; break;
case "non potrà modificare la <b>data iniziale o finale</b> delle prenotazioni nel":	$messaggio = "il ne pourra pas modifier les <b>dates de déburt ou de fin</b> des réservations dans"; break;
case "potrà modificare la <b>data iniziale o finale</b> delle prenotazioni nel":	$messaggio = "il pourra modifier les <b>dates de déburt ou de fin</b> des réservations dans"; break;
case "non potrà modificare la <b>tariffa</b> delle prenotazioni nel":	$messaggio = "il ne pourra pas modifier les <b>tarifs</b> des réservations dans"; break;
case "potrà modificare la <b>tariffa</b> delle prenotazioni, scegliendo se utilizzare la regola 2, nel":	$messaggio = "il pourra modifier les <b>tarifs</b> des réservations, sélectionnés dans la règle 2, dans"; break;
case "non potrà modificare il <b>numero delle persone</b> delle prenotazioni nel":	$messaggio = "il ne pourra pas modifier les <b>nombre de personnes</b> des réservations dans"; break;
case "potrà modificare il <b>numero delle persone</b> delle prenotazioni nel":	$messaggio = "il pourra modifier les <b>nombre de personnes</b> des réservations dans"; break;
case "non potrà modificare il <b>commento</b> delle prenotazioni nel":	$messaggio = "il ne pourra pas modifier les <b>commentaires</b> des réservations dans"; break;
case "potrà modificare il <b>commento</b> delle prenotazioni nel":	$messaggio = "il pourra modifier les <b>commentaires</b> des réservations dans"; break;
case "non potrà modificare lo <b>sconto</b> delle prenotazioni nel":	$messaggio = "il ne pourra pas modifier les <b>escomptes</b> des réservations dans"; break;
case "potrà modificare lo <b>sconto</b> delle prenotazioni nel":	$messaggio = "il pourra modifier the <b>escomptes</b> des réservations dans"; break;
case "non potrà modificare i <b>costi aggiuntivi</b> delle prenotazioni nel":	$messaggio = "il ne pourra pas modifier les <b>surcoûts</b> des réservations dans"; break;
case "potrà modificare i <b>costi aggiuntivi</b> delle prenotazioni nel":	$messaggio = "il pourra modifier les <b>surcoûts</b> des réservations dans"; break;
case "non potrà modificare i <b>soldi pagati</b> e la <b>conferma</b> delle prenotazioni nel":	$messaggio = "il ne pourra pas modifier <b>l'argent payé</b> et la <b>confirmation</b> des réservations dans"; break;
case "non potrà modificare i <b>soldi pagati</b> ma solo la <b>conferma</b> delle prenotazioni nel":	$messaggio = "il ne pourra pas modifier <b>l'argent payé</b> mais seulement les <b>confirmation</b> des réservations dans"; break;
case "potrà modificare i <b>soldi pagati</b> e la <b>conferma</b> delle prenotazioni nel":	$messaggio = "il pourra modifier <b>l'argent payé</b> et la <b>confirmation</b> des réservations dans"; break;
case "non potrà modificare le <b>prenotazioni già iniziate</b> nel":	$messaggio = "il ne pourra pas modifier <b>les réservations déja entamées</b> dedans"; break;
case "potrà modificare anche le <b>prenotazioni già iniziate</b> nel":	$messaggio = "il pourra modifier même <b>les réservations déja entamées</b> dedans"; break;
case "non avrà <b>limite di tempo</b> per modificare le prenotazioni nel":	$messaggio = "Il n'aura aucun délai pour modifier des réservations"; break;
case "non potrà più modificare le prenotazioni <b>dopo":	$messaggio = "il ne pourra plus modifier les réservations <b>après"; break;
case "non potrà <b>cancellare</b> nessuna prenotazione nel":	$messaggio = "il ne pourra pas <b>supprimer</b> aucune réservation dedans"; break;
case "potrà <b>cancellare</b> tutte le prenotazioni nel":	$messaggio = "il pourra <b>supprimer</b> toutes les réservations dedans"; break;
case "non avrà <b>limite di tempo</b> per cancellare le prenotazioni nel":	$messaggio = "il ne sera pas <b>limité dans le temps</b> pour supprimer les réservations dans"; break;
case "ore</b> nel":  				$messaggio = "heures</b> dans"; break;
case "non potrà più cancellare le prenotazioni <b>dopo":	$messaggio = "il ne pourra pas supprimer les réservations <b>après"; break;
case "non potrà inserire le <b>spese</b> nel":	$messaggio = "il ne pourra pas insérer les <b>paiements</b> dans"; break;
case "potrà inserire le <b>spese</b> nel":  	$messaggio = "il pourra insérer les <b>paiements</b> dans"; break;
case "non potrà inserire le <b>entrate</b> nel":	$messaggio = "il ne pourra pas insérer les <b>reçus</b> dedans"; break;
case "potrà inserire le <b>entrate</b> nel":	$messaggio = "il pourra insérer les <b>reçus</b> dedans"; break;
case "Le entrate inserite non verranno mai <b>sottratte</b> dal totale delle prenotazioni nel":	$messaggio = "Les reçus insérés dedans ne seront jamais soustraits du total des réservations"; break;
case "potrà decidere se <b>sottrarre</b> le entrate dal totale delle prentazioni nel":	$messaggio = "il pourra <b>soustraire</b> les reçus insérés dedans du total des réservations"; break;
case "Le entrate inserite verranno sempre <b>sottratte</b> dal totale delle prenotazioni nel":	$messaggio = "Les reçus insérés dedans seront toujours <b>soustraites</b> du total des réservations"; break;
case "Non verrà inserito nessuno come <b>persona</b> che inserisce le spese o le entrate nel":	$messaggio = "Personne ne sera inséré en tant que <b>personne</b> qui insère les reçus et les paiements dedans"; break;
case "potrà scegliere chi inserire come <b>persona</b> che inserisce le spese e le entrate nel":	$messaggio = "il pourra choisir qui insérer <b>comme personne</b> qui insère les frais et les entrées dans"; break;
case "Verrà sempre inserito il nome dell'utente":	$messaggio = "Il sera toujours inséré le nom de l'utilisateur"; break;
case "come <b>persona</b> che inserisce le spese e le entrate nel": 	$messaggio = "en tant que <b>personne</b> qui insère les reçus et les paiements dedans"; break;
case "non potrà vedere le <b>tabelle dei mesi</b> del":	$messaggio = "il ne pourra pas voir les <b>tableaux des mois</b> de"; break;
case "potrà vedere le <b>tabelle dei mesi</b> del":	$messaggio = "il pourra voir les <b>tableaux des mois</b> de"; break;
case "non potrà vedere la <b>tabella con tutte le prenotazioni</b> del":	$messaggio = "il ne pourra pas voir les <b>tableaux avec toutes les réservations</b> de"; break;
case "potrà vedere solo le proprie prenotazioni nella <b>tabella con tutte le prenotazioni</b> del":	$messaggio = "il pourra voir seulement ses propres réservations dans les <b>tableaux avec toutes les réservations"; break;
case "potrà vedere la <b>tabella con tutte le prenotazioni</b> del":	$messaggio = "il pourra voir les <b>tableaux avec toutes les réservations</b> de"; break;
case "non potrà vedere le <b>tabelle con le entrate e le uscite</b> del":	$messaggio = "il ne pourra pas voir les <b>tableaux avec les reçus et les paiements</b> de"; break;
case "potrà vedere solo le proprie entrate/uscite nelle <b>tabelle con le entrate e le uscite</b> del":	$messaggio = "il pourra voir seulemnts ses reçus/paiements dans les <b>tableaux avec les reçus et les paiements</b> de"; break;
case "potrà vedere solo le entrate/uscite sue e di utenti appartenenti ai suoi gruppi nelle <b>tabelle con le entrate e le uscite</b> del":	$messaggio = "will be able to view only receipts/payments from him and from users belonging to his groups in the <b>table with the receipts and the payments</b> of"; break;
case "potrà vedere le <b>tabelle con le entrate e le uscite</b> del":	$messaggio = "il pourra voir les <b>les <b>tableaux avec les reçus et les paiements</b> de"; break;
case "non potrà vedere la <b>tabella con i periodi e le tariffe</b> del":	$messaggio = "il ne pourra pas voir le <b>tableau avec les périodes et les tarifs</b> de"; break;
case "potrà vedere solo le tariffe a lui consentite nella <b>tabella con i periodi e le tariffe</b> del":	$messaggio = "il pourra voir seulement ses tarifs permis dans <b>le tableau avec les périodes et les tarifs</b> de"; break;
case "potrà vedere la <b>tabella con i periodi e le tariffe</b> del":	$messaggio = "il pourra voir <b>le tableau avec les périodes et les tarifs</b> de"; break;
case "non potrà vedere la <b>tabella con le regole di assegnazione</b> del":	$messaggio = "il ne pourra pas voir le <b>tableau les règles d'attribution</b> de"; break;
case "potrà vedere solo le regole a lui consentite nella <b>tabella con le regole di assegnazione</b> del":	$messaggio = "il pourra voir seulement ses règles permisent dans le <b>tableau des règles d'attribution</b> de"; break;
case "potrà vedere la <b>tabella con le regole di assegnazione</b> del":	$messaggio = "il pourra voir le <b>tableau des règles d'attribution</b> de"; break;
case "Possibilità di inserire più prenotazioni contemporaneamente":	$messaggio = "Possibilité d'insérer plusieurs réservations en même temps"; break;
case "non potrà inserire <b>più prenotazioni contemporaneamente</b> nel":	$messaggio = "il ne pourra pas insérer <b>plusieurs réservations en même temps</b> dans"; break;
case "potrà inserire <b>più prenotazioni contemporaneamente</b> nel":	$messaggio = "il pourra insérer <b>plusieurs réservations en même temps</b> dans"; break;
case "Prenotazioni non più cancellabili dopo essere state confermate":	$messaggio = "Réservations non supprimables après avoir été confirmé"; break;
case "non potrà <b>cancellare</b> le prenotazioni confermate nel":	$messaggio = "il ne pourra pas <b>supprimer</b> les réservations confirmés dedans"; break;
case "potrà <b>cancellare</b> le prenotazioni confermate nel":	$messaggio = "il pourra <b>supprimer</b> les réservations confirmés dedans"; break;
case "Possibilità di modificare l'orario di entrata ed uscita":	$messaggio = "Possibilité de modifier les horaire d'entrée et sortie"; break;
case "non potrà modificare l'orario di <b>entrata ed uscita</b> delle prenotazioni nel":	$messaggio = "il ne pourra pas modifier <b>les horaire d'entrée et sortie</b> des réservations dans"; break;
case "potrà modificare l'orario di <b>entrata ed uscita</b> delle prenotazioni nel":	$messaggio = "il pourra modifier <b>les horaire d'entrée et sortie</b> des réservations dans"; break;
case "potrà inserire <b>più prenotazioni contemporaneamente ma non vicine</b> nel":	$messaggio = "will be able to insert <b>more reservations contemporarely but not in close apartments</b> in"; break;
case "Possibilità di modificare le prenotazioni vicine":	$messaggio = "Possibility to modify close reservations"; break;
case "non potrà modificare le <b>prenotazioni vicine</b> nel":	$messaggio = "will not be able to modify <b>close reservations</b> in"; break;
case "potrà modificare le <b>prenotazioni vicine</b> nel":	$messaggio = "will be able to modify <b>close reservations</b> in"; break;
case "nel":  					$messaggio = "in"; break;
case "Solo":  					$messaggio = "Only"; break;
case "i propri":  				$messaggio = "his own"; break;
case "dei propri":  				$messaggio = "his own"; break;
case "Permetti la visualizzazione di tutti i <i>documenti</i>":	$messaggio = "Permit the visualization of all <i>documents</i>"; break;
case "Permetti la visualizzazione solo dei <i>documenti</i> selezionati":	$messaggio = "Permit the visualization of selected <i>documents</i> only"; break;
case "documento":  				$messaggio = "document"; break;
case "Possibilità di inserire la caparra e le commissioni":	$messaggio = "Possibility to insert deposit and commissions"; break;
case "Possibilità di inserire il commento":  	$messaggio = "Possibility to insert the comment"; break;
case "Possibilità di inserire i commenti personalizzati":	$messaggio = "Possibility to insert custom comments"; break;
case "le proprie":  				$messaggio = "own ones"; break;
case "dei suoi gruppi":  			$messaggio = "from his groups"; break;
case "Possibilità di vedere il commento":  	$messaggio = "Possibility to view the comment"; break;
case "Possibilità di vedere e modificare i commenti personalizzati":	$messaggio = "Possibility to view and modify custom comments"; break;
case "Possibilità di modificare la caparra e le commissioni":  	$messaggio = "Possibility to modify deposit and commissions"; break;
case "Solo con":				$messaggio = "Only with"; break;
case "prenotazioni proprie":			$messaggio = "own reservations"; break;
case "prenotazioni dai suoi gruppi":		$messaggio = "reservations from his groups"; break;
case "a lui":					$messaggio = "to him"; break;
case "ai suoi gruppi":				$messaggio = "to his groups"; break;
case "Si deve inserire il <div style=\"display: inline; color: red;\">prefisso/suffisso</div> da utilizzare per i clienti dell'utente":	$messaggio = "You must insert the <div style=\"display: inline; color: red;\">prefix/suffix</div> to be used for clients of user"; break;
case "e quelli di utenti appartenenti ai suoi gruppi":	$messaggio = "and the ones from users belonging to his groups"; break;
case "Anno <div style=\"display: inline; color: red;\">errato</div>":	$messaggio = "<div style=\"display: inline; color: red;\">Wrong</div> year"; break;
case "Ore in cui si può modificare la prenotazione <div style=\"display: inline; color: red;\">errate</div>":	$messaggio = "Hours in which is possible to modify reservations are <div style=\"display: inline; color: red;\">wrong</div>"; break;
case "Ore in cui si può cancellare la prenotazione <div style=\"display: inline; color: red;\">errate</div>":	$messaggio = "Hours in which is possible to delete reservations are <div style=\"display: inline; color: red;\">wrong</div>"; break;
case "se non vi può inserire prenotazioni":	$messaggio = "if he can't insert reservations there"; break;
case "potrà visualizzare <b>tutti i documenti</b> del":	$messaggio = "will be able to view <b>all documents</b> of"; break;
case "potrà visualizzare solo i <b>documenti selezionati</b> del":	$messaggio = "will be able to view only <b>selected documents</b> of"; break;
case "Verranno cambiati i <b>documenti</b> visualizzabili per l'anno":	$messaggio = "<b>Selected documents</b> will be changed for year"; break;
case "non potrà inserire la <b>caparra</b> e le <b>commissioni</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will not be able to insert the <b>deposit</b> and the <b>commissions</b> when he inserts new reservations in"; break;
case "potrà inserire la <b>caparra</b> e le <b>commissioni</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will be able to insert the <b>deposit</b> and the <b>commissions</b> when he inserts new reservations in"; break;
case "non potrà inserire il <b>commento</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will not be able to insert the <b>comment</b> when inserts new reservations in"; break;
case "potrà inserire il <b>commento</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will be able to insert the <b>comment</b> when inserts new reservations in"; break;
case "non potrà inserire i <b>commenti personalizzati</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will not be able to insert <b>custom comments</b> when inserts new reservations in"; break;
case "potrà inserire i <b>commenti personalizzati</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will be able to insert <b>custom comments</b> when inserts new reservations in"; break;
case "potrà modificare solo le <b>sue prenotazioni</b> e quelle di utenti appartenenti ai suoi gruppi nel":	$messaggio = "will be able to modify only his <b>own reservations</b> and those owned by users belonging to his groups in"; break;
case "non potrà vedere il <b>commento</b> delle prenotazioni nel":	$messaggio = "will not be able to view the <b>comment</b> of reservations in"; break;
case "potrà vedere il <b>commento</b> delle prenotazioni nel":	$messaggio = "will be able to view the <b>comment</b> of reservations in"; break;
case "non potrà vedere e modificare i <b>commenti personalizzati</b> delle prenotazioni nel":	$messaggio = "will not be able to view and modify <b>custom comments</b> of reservations in"; break;
case "potrà vedere e modificare i <b>commenti personalizzati</b> delle prenotazioni nel":	$messaggio = "will be able to view and modify <b>custom comments</b> of reservations in"; break;
case "non potrà modificare la <b>caparra</b> e le <b>commissioni</b> delle prenotazioni nel":	$messaggio = "will not be able to modify the <b>deposit</b> and the <b>commissions</b> of reservations in"; break;
case "potrà modificare la <b>caparra</b> e le <b>commissioni</b> delle prenotazioni nel":	$messaggio = "will be able to modify the <b>deposit</b> and the <b>commissions</b> of reservations in"; break;
case "potrà <b>cancellare</b> solo le prenotazioni non iniziate nel":	$messaggio = "will be able to <b>delete</b> only not begun reservations in"; break;
case "nelle <b>tabelle dei mesi</b> del":  	$messaggio = "in the <b>months tables</b> of"; break;
case "potrà vedere solo le prenotazioni sue e di utenti appartenenti ai suoi gruppi nella <b>tabella con tutte le prenotazioni</b> del":	$messaggio = "will be able to view only reservations from him and from users belonging to his groups in the <b>table with all reservations</b> of"; break;
case "potrà vedere solo le tariffe consentite a lui e ad utenti dei suoi gruppi nella <b>tabella con i periodi e le tariffe</b> del":	$messaggio = "will be able to view only rates permitted to him and to users of his groups in the <b>table with the periods and the rates</b> of"; break;
case "potrà vedere solo le regole consentite a lui e ad utenti dei suoi gruppi nella <b>tabella con le regole di assegnazione</b> del":	$messaggio = "will be able to view only rules permitted to him and to users of his groups in the <b>table with the assignment rules</b> of"; break;
case "Possibilità di vedere i messaggi ricevuti":	$messaggio = "Possibility to view received messages"; break;
case "Possibilità di mandare messaggi":  	$messaggio = "Possibility to send messages"; break;
case "non potrà vedere <b>i messaggi ricevuti</b>":	$messaggio = "will not be able to view <b>received messages</b>"; break;
case "potrà vedere <b>i messaggi ricevuti</b>":	$messaggio = "will be able to view <b>received messages</b>"; break;
case "non potrà <b>inviare messaggi</b>":	$messaggio = "will not be able to <b>send messages</b>"; break;
case "potrà <b>inviare messaggi</b>":  		$messaggio = "will be able to <b>send messages</b>"; break;
case "Possibilità di inserire l'orario di entrata":	$messaggio = "Possibility to insert the checkin hour"; break;
case "non potrà inserire l'<b>orario di entrata</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will not be able to change the <b>checkin hour</b> when inserts new reservations in"; break;
case "potrà inserire la l'<b>orario di entrata</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will be able to change the <b>checkin hour</b> when inserts new reservations in"; break;
case "non potrà vedere e modificare il <b>codice prenotazione</b> nel":	$messaggio = "will not be able to view and modify the <b>reservation code</b> in"; break;
case "potrà vedere e modificare il <b>codice prenotazione</b> nel":	$messaggio = "will be able to view and modify the <b>reservation code</b> in"; break;
case "Possibilità di vedere e modificare il codice prenotazione":	$messaggio = "Possibility to view and modify the reservation code"; break;
case "Possibilità di cambiare il cliente con un altro":	$messaggio = "Possibility to change the client with another one"; break;
case "potrà cambiare il <b>cliente</b> delle prenotazioni nel":	$messaggio = "will be able to change the <b>client</b> of reservations in"; break;
case "non potrà cambiare il <b>cliente</b> delle prenotazioni nel":	$messaggio = "will not be able to change the <b>client</b> of reservations in"; break;
case "Possibilità di inserire l'origine":  	$messaggio = "Possibility to insert the origin"; break;
case "Possibilità di modificare l'origine":  	$messaggio = "Possibility to modify the origin"; break;
case "potrà inserire <b>l'origine della prenotazione</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will be able to insert the <b>reservation origin</b> when inserts new reservations in"; break;
case "non potrà inserire <b>l'origine della prenotazione</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will not be able to insert the <b>reservation origin</b> when inserts new reservations in"; break;
case "potrà modificare il <b>l'origine</b> delle prenotazioni nel":	$messaggio = "will be able to modify the <b>origin</b> of reservations in"; break;
case "non potrà modificare <b>l'origine</b> delle prenotazioni nel":	$messaggio = "will not be able to modify the <b>origin</b> of reservations in"; break;
case "Possibilità di modificare le <i>tariffe</i> a lui permesse":	$messaggio = "Possibility to modify the <i>rates</i> permitted to him"; break;
case "Possibilità di inserire <i>nuovi costi aggiuntivi</i>":	$messaggio = "Possibility to insert <i>new extra costs</i>"; break;
case "rendendoli disponibili":			$messaggio = "making them available"; break;
case "solo a lui":  				$messaggio = "only to him"; break;
case "a utenti dei suoi gruppi":  		$messaggio = "to users from his groups"; break;
case "Possibilità di modificare i <i>costi aggiuntivi</i> a lui permessi":	$messaggio = "Possibility to modify the <i>extra costs</i> permitted to him"; break;
case "non potrà modifcare le <b>tariffe a lui permesse</b> nel":	$messaggio = "will not be able to modify the <b>rates pemitted to him</b> in"; break;
case "potrà modifcare le <b>tariffe a lui permesse</b> nel":	$messaggio = "will be able to modify the <b>rates pemitted to him</b> in"; break;
case "non potrà inserire <b>nuovi costi aggiuntivi</b> nel":	$messaggio = "will not be able to insert <b>new extra costs</b> in"; break;
case "potrà inserire <b>nuovi costi aggiuntivi</b> il cui utilizzo sarà permesso a lui e agli utenti appartenenti ai suoi stessi gruppi nel":	$messaggio = "will be able to insert <b>new extra costs</b> which utilization will be permitted to him and to users belonging to his groups in"; break;
case "potrà inserire <b>nuovi costi aggiuntivi</b> il cui utilizzo sarà permesso solo a lui nel":	$messaggio = "will be able to insert <b>new extra costs</b> which utilization will be permitted only to him in"; break;
case "non potrà modifcare i <b>costi aggiuntivi lui permessi</b> nel":	$messaggio = "will not be able to modify the <b>extra costs pemitted to him</b> in"; break;
case "potrà modifcare i <b>costi aggiuntivi lui permessi</b> nel":	$messaggio = "will be able to modify the <b>extra costs pemitted to him</b> in"; break;
case "Possibilità di cancellare i <i>costi aggiuntivi</i> a lui permessi":	$messaggio = "Possibility to delete the <i>extra costs</i> permitted to him"; break;
case "non potrà cancellare i <b>costi aggiuntivi lui permessi</b> nel":	$messaggio = "will not be able to delete the <b>extra costs pemitted to him</b> in"; break;
case "potrà cancellare i <b>costi aggiuntivi lui permessi</b> nel":	$messaggio = "will be able to delete the <b>extra costs pemitted to him</b> in"; break;
case "nelle <b>statistiche</b> del":  		$messaggio = "in the <b>statistics</b> of"; break;
case "non potrà vedere le <b>statistiche</b> del":	$messaggio = "will not be able to view the <b>statistics</b> of"; break;
case "potrà vedere le <b>statistiche</b> del":	$messaggio = "will be able to view the <b>statistics</b> of"; break;
case "Possibilità di vedere <i>le statistiche</i>":	$messaggio = "Possibility to view <i>the statistics</i>"; break;
case "Possibilità di vedere i <i>beni dell'inventario</i>":	$messaggio = "Possibility to view <i>inventory items</i>"; break;
case "Possibilità di inserire nuovi beni nell'inventario":	$messaggio = "Possibility to insert new inventory items"; break;
case "Possibilità di vedere l'<i>inventario dei magazzini</i>":	$messaggio = "Possibility to view <i>stockrooms inventory</i>"; break;
case "Possibilità di inserire nuovi magazzini":	$messaggio = "Possibility to insert new stockrooms"; break;
case "Possibilità di aggiungere e cancellare beni":	$messaggio = "Possibility to add and delete items"; break;
case "Solo in":  				$messaggio = "Only in"; break;
case "magazzini propri":  			$messaggio = "own stockrooms"; break;
case "magazzini dei suoi gruppi":  		$messaggio = "stockrooms from his groups"; break;
case "Possibilità di modificare le quantità dei beni":	$messaggio = "Possibility to modify items quantity"; break;
case "non potrà vedere i <b>beni dell'inventario</b>":	$messaggio = "will not be able to view the <b>inventory items</b>"; break;
case "potrà vedere solo i <b>suoi beni dell'inventario</b>":	$messaggio = "will be able to view only <b>his own inventory items</b>"; break;
case "potrà vedere i <b>beni dell'inventario</b>":	$messaggio = "will be able to view the <b>inventory items</b>"; break;
case "non potrà <b>inserire nuovi beni</b> nell'inventario":	$messaggio = "will not be able to <b>insert new items</b> in inventory"; break;
case "potrà <b>inserire nuovi beni</b> nell'inventario":	$messaggio = "will be able to <b>insert new items</b> in inventory"; break;
case "non potrà vedere <b>l'inventario":  	$messaggio = "will not be able to view the <b>inventory"; break;
case "potrà vedere <b>l'inventario":  		$messaggio = "will be able to view the <b>inventory"; break;
case "dei magazzini</b>":  			$messaggio = "of stockrooms</b>"; break;
case "solo dei suoi magazzini</b>":  		$messaggio = "only of his own stockrooms</b>"; break;
case "e di quelli di utenti appartenenti ai suoi gruppi":	$messaggio = "and of those from users belonging to his groups"; break;
case "non potrà <b>inserire nuovi magazzini</b>":	$messaggio = "will not be able to <b>insert new stockrooms</b>"; break;
case "potrà <b>inserire nuovi magazzini</b>":	$messaggio = "will be able to <b>insert new stockrooms</b>"; break;
case "non potrà <b>aggiungere e cancellare beni</b>":	$messaggio = "will not be able to <b>add or delete items</b>"; break;
case "potrà <b>aggiungere e cancellare beni</b>":	$messaggio = "will be able to <b>add or delete items</b>"; break;
case "nei magazzini":  				$messaggio = "in stockrooms"; break;
case "solo nei suoi magazzini":  		$messaggio = "only in is own stockrooms"; break;
case "e in quelli di utenti appartenenti ai suoi gruppi":	$messaggio = "and in those from users belonging to his groups"; break;
case "non potrà <b>modificare le quantità dei beni</b>":	$messaggio = "will not be able to <b>modify items quantity</b>"; break;
case "potrà <b>modificare le quantità dei beni</b>":	$messaggio = "will be able to <b>modify items quantity</b>"; break;
case "creazione, download e cancellazione del backup completo":	$messaggio = "create, download and delete the complete backup"; break;
case "potrà creare i <b>backup</b>":  		$messaggio = "will be able to create <b>backups</b>"; break;
case "non potrà più creare i <b>backup</b>":  	$messaggio = "will not be able to create <b>backups</b>"; break;
case "Possibilità di vedere la <i>tabella con i documenti salvati</i>":	$messaggio = "Possibility to view the <i>table with saved documents</i>"; break;
case "Solo con documenti consentiti":  		$messaggio = "Only with documents permitted"; break;
case "non potrà vedere la <b>tabella con i documenti salvati</b> del":	$messaggio = "will not be able to view the <b>table with saved documents</b> of"; break;
case "potrà vedere solo i documenti a lui consentiti nella <b>tabella con i documenti salvati</b> del":	$messaggio = "will be able to view only documents permitted to him in the <b>table with saved documents</b> of"; break;
case "potrà vedere la <b>tabella con i documenti salvati</b> del":	$messaggio = "will be able to view the <b>table with saved documents</b> of"; break;
case "Permetti l'uso solo delle <i>casse</i> selezionate":	$messaggio = "Permit the usage of selected <i>cashboxes</i> only"; break;
case "Permetti l'uso di tutte le <i>casse</i>":	$messaggio = "Permit the usage of all <i>cashboxes</i>"; break;
case "cassa principale":  			$messaggio = "main cashbox"; break;
case "potrà usare <b>tutte le casse</b>":  	$messaggio = "will be able to use <b>all cashboxes</b>"; break;
case "potrà usare solo le <b>casse selezionate</b>":	$messaggio = "will be able to use only <b>selected cashboxes</b>"; break;
case "Verranno cambiate le <b>casse</b> utilizzabili":	$messaggio = "The <b>cashboxes</b> that can be used will be changed"; break;
case "Inserire sempre i pagamenti delle prenotazioni nella cassa":	$messaggio = "Always insert reservations payments in cashbox"; break;
case "I pagamenti inseriti nelle prenotazioni dall'utente":	$messaggio = "Payments inserted in reservations by user"; break;
case "verranno anche registrati come entrate nella cassa chiamata":	$messaggio = "will be also registered as incomes in cashbox called"; break;
case "non verranno registrati in cassa nel":	$messaggio = "will not be registered in any cashbox in"; break;
case "Modifica dei documenti":  		$messaggio = "Modify documents"; break;
case "potrà modificare i <b>documenti</b>":  	$messaggio = "will be able to modify <b>documents</b>"; break;
case "non potrà più modificare i <b>documenti</b>":	$messaggio = "will not be able to modify <b>documents</b> anymore"; break;
case "Possibilità di vedere email, telefoni e fax dei clienti":	$messaggio = "Possibility to view emails, telephones and faxes of clients"; break;
case "Possibilità di vedere l'indirizzo dei clienti":	$messaggio = "Possibility to view the address of clients"; break;
case "potrà vedere <b>email, telefoni e fax</b> dei clienti":	$messaggio = "will be able to view <b>emails, telephones and faxes</b> of clients"; break;
case "non potrà più vedere <b>email, telefoni e fax</b> dei clienti":	$messaggio = "will not be able to view <b>emails, telephones and faxes</b> of clients"; break;
case "potrà vedere <b>l'indirizzo</b> dei clienti":	$messaggio = "will be able to view <b>the address</b> of clients"; break;
case "non potrà più vedere <b>l'indirizzo</b> dei clienti":	$messaggio = "will not be able to view <b>the address</b> of clients"; break;
case "Mostrare le prenotazioni non permesse come":	$messaggio = "Show not permitted reservations as"; break;
case "oscurate":  				$messaggio = "obscured"; break;
case "periodi vuoti":  				$messaggio = "empty periods"; break;
case "solo correnti e future":  		$messaggio = "only current and future"; break;
case "vedrà le prenotazioni non permesse come <em>oscurate</em>":	$messaggio = "will see not permitted reservations as <em>obscured</em>"; break;
case "vedrà le prenotazioni non permesse come <em>periodi vuoti</em>":	$messaggio = "will see not permitted reservations as <em>empty periods</em>"; break;
case "vedrà le prenotazioni non permesse come <em>periodi vuoti nel passato ed oscurate nel presente e nel futuro</em>":	$messaggio = "will see not permitted reservations as <em>empty periods in the past, obscured in the present and future</em>"; break;
case "Possibilità di cancellare o sovrascrivere i documenti salvati":	$messaggio = "Possibility to delete and overwrite saved documents"; break;
case "potrà <b>cancellare e sovrascrivere i documenti</b> salvati nel":	$messaggio = "will be able to <b>delete and overwrite documents</b> saved in"; break;
case "non potrà <b>cancellare e sovrascrivere i documenti</b> salvati nel":	$messaggio = "will not be able to <b>delete and overwrite documents</b> saved in"; break;
case "Creazione e modifica delle interconnessioni":	$messaggio = "Create and modify interconnections"; break;
case "potrà creare e modificare le <b>interconnessioni</b>":	$messaggio = "will be able to create and modify <b>interconnections</b>"; break;
case "non potrà più creare e modificare le <b>interconnessioni</b>":	$messaggio = "will not be able to create and modify <b>interconnections</b>"; break;
case "Modifica dei documenti come API":  	$messaggio = "Modify documents as API"; break;
case "potrà modificare i <b>documenti come API</b>":	$messaggio = "will be able to modify <b>documents as API</b>"; break;
case "Attenzione":  				$messaggio = "Warning"; break;
case "questo può consentire l'accesso ai dati di tutte le prenotazioni":	$messaggio = "this can allow access to data of all reservations"; break;
case "non potrà più modificare i <b>documenti come API</b>":	$messaggio = "will not be able to modify <b>documents as API</b> anymore"; break;
case "Gestione della password per le carte di credito":	$messaggio = "Management of credit cards password"; break;
case "potrà gestire la <b>password per le carte di credito</b>":	$messaggio = "will be able to manage the <b>credit cards password</b>"; break;
case "non potrà più gestire la <b>password per le carte di credito</b>":	$messaggio = "will not be able to manage the <b>credit cards password</b>"; break;
case "senza mostrare il valore":  		$messaggio = "without showing the value"; break;
case "mostrando il valore":  			$messaggio = "showing the value"; break;
case "senza mostrare i valori":  		$messaggio = "without showing the values"; break;
case "mostrando i valori":  			$messaggio = "showing the values"; break;
case "Possibilità di modificare l'utente che ha inserito":	$messaggio = "Possibility to modify the inserting user"; break;
case "con tutti gli utenti":  			$messaggio = "with all users"; break;
case "solo con utenti dei suoi gruppi":  	$messaggio = "only with users from his groups"; break;
case "mostrando l'utente":  			$messaggio = "showing the user"; break;
case "senza mostrare l'utente":  		$messaggio = "without showing the user"; break;
case "potrà modificare l'<b>utente</b> che ha inserito la prenotazione nel":	$messaggio = "will be able to modify the <b>user</b> that inserted the reservation in"; break;
case "non potrà modificare l'<b>utente</b> che ha inserito la prenotazione nel":	$messaggio = "will not be able to modify the <b>user</b> that inserted the reservation in"; break;
case "senza mostrarla":  			$messaggio = "without showing it"; break;
case "senza mostrarli":  			$messaggio = "without showing them"; break;
case "Modifica delle tipologie di persone":  	$messaggio = "Modify people types"; break;
case "potrà modificare le sue <b>tipologie di persone</b>":	$messaggio = "will be able to modify his <b>people types</b>"; break;
case "non potrà più modificare le sue <b>tipologie di persone</b>":	$messaggio = "will not be able to modify his <b>people types</b>"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>